@@ -69,7 +69,7 @@ class FormField(py_cui.ui.TextBoxImplementation):
 
     def is_required(self) -> bool:
         """Checks if field is required
-        
+
         Returns
         -------
         required : bool
@@ -164,7 +164,7 @@ class FormFieldElement(py_cui.ui.UIElement, FormField):
             self._move_left()
         elif key_pressed == py_cui.keys.KEY_RIGHT_ARROW:
             self._move_right()
-        elif key_pressed == py_cui.keys.KEY_BACKSPACE:
+        elif key_pressed in py_cui.keys.KEY_BACKSPACE:
             self._erase_char()
         elif key_pressed == py_cui.keys.KEY_DELETE:
             self._delete_char()
@@ -225,7 +225,7 @@ class FormImplementation(py_cui.ui.UIImplementation):
         super().__init__(logger)
         self._form_fields = field_implementations
         self._required_fields = required_fields
-        
+
         self._selected_form_index = 0
         self._on_submit_action: Optional[Callable[[],Any]] = None
 
@@ -366,17 +366,17 @@ class FormPopup(py_cui.popups.Popup, FormImplementation):
             init_text = ''
             if field in fields_init_text:
                 init_text = fields_init_text[field]
-            self._form_fields.append(FormFieldElement(self, 
-                                              i, 
-                                              field, 
-                                              init_text, 
-                                              (field in passwd_fields), 
-                                              (field in required_fields), 
+            self._form_fields.append(FormFieldElement(self,
+                                              i,
+                                              field,
+                                              init_text,
+                                              (field in passwd_fields),
+                                              (field in required_fields),
                                               renderer,
                                               logger))
         self._form_fields[0].set_selected(True)
         FormImplementation.__init__(self, self._form_fields, required_fields, logger)
-        
+
         self._internal_popup = None
 
 
@@ -394,7 +394,7 @@ class FormPopup(py_cui.popups.Popup, FormImplementation):
 
     def get_absolute_start_pos(self) -> Tuple[int,int]:
         """Override of base class, computes position based on root dimensions
-        
+
         Returns
         -------
         start_x, start_y : int
@@ -410,9 +410,9 @@ class FormPopup(py_cui.popups.Popup, FormImplementation):
         min_required_y = 4 + (2 * self._pady) + 5 * self._num_fields
         if root_height < min_required_y:
             min_required_y = root_height
-        
+
         form_start_x = int(root_width / 2) - int(min_required_x / 2)
-        
+
         form_start_y = int(root_height / 2) - int(min_required_y / 2)
 
         return form_start_x, form_start_y
@@ -420,7 +420,7 @@ class FormPopup(py_cui.popups.Popup, FormImplementation):
 
     def get_absolute_stop_pos(self) -> Tuple[int,int]:
         """Override of base class, computes position based on root dimensions
-        
+
         Returns
         -------
         stop_x, stop_y : int
@@ -436,9 +436,9 @@ class FormPopup(py_cui.popups.Popup, FormImplementation):
         min_required_y = 4 + (2 * self._pady) + 5 * self._num_fields
         if root_height < min_required_y:
             min_required_y = root_height
-        
+
         form_stop_x = int(root_width / 2) + int(min_required_x / 2)
-        
+
         form_stop_y = int(root_height / 2) + int(min_required_y / 2)
 
         return form_stop_x, form_stop_y
@@ -479,14 +479,14 @@ class FormPopup(py_cui.popups.Popup, FormImplementation):
                 if valid:
                     self._root.close_popup()
                     if self._on_submit_action is not None:
-                        self._on_submit_action(self.get()) 
+                        self._on_submit_action(self.get())
                 else:
                     self._internal_popup = InternalFormPopup(self,
-                                                             self._root, 
-                                                             err_msg, 
+                                                             self._root,
+                                                             err_msg,
                                                              f'Required fields: {str(self._required_fields)}',
-                                                             py_cui.YELLOW_ON_BLACK, 
-                                                             self._renderer, 
+                                                             py_cui.YELLOW_ON_BLACK,
+                                                             self._renderer,
                                                              self._logger)
             elif key_pressed == py_cui.keys.KEY_ESCAPE:
                 self._root.close_popup()
@@ -519,7 +519,7 @@ class FormPopup(py_cui.popups.Popup, FormImplementation):
 
     def _draw(self) -> None:
         """Override of base class.
-        
+
         Here, we only draw a border, and then the individual form elements
         """
 
