@@ -7,6 +7,7 @@ The grid is currently the only supported layout manager for py_cui
 # Created:   12-Aug-2019
 
 
+from typing import Tuple
 import py_cui
 
 
@@ -23,12 +24,14 @@ class Grid:
         The number of additional characters found by height mod rows and width mod columns
     _row_height, _column_width : int
         The number of characters in a single grid row, column
+    _title_bar_offset : int
+        Title bar row offset. Defaults to 1. Set to 0 if title bar is hidden.
     _logger : py_cui.debug.PyCUILogger
         logger object for maintaining debug messages
     """
 
 
-    def __init__(self, num_rows, num_columns, height, width, logger):
+    def __init__(self, num_rows: int, num_columns: int, height: int, width: int, logger: 'py_cui.debug.PyCUILogger'):
         """Constructor for the Grid class
 
         Parameters
@@ -51,10 +54,11 @@ class Grid:
         self._offset_y      = self._height  % self._num_rows    - 1
         self._row_height    = int(self._height   / self._num_rows)
         self._column_width  = int(self._width    / self._num_columns)
+        self._title_bar_offset = 1
         self._logger        = logger
 
 
-    def get_dimensions(self):
+    def get_dimensions(self) -> Tuple[int,int]:
         """Gets dimensions in rows/columns
 
         Returns
@@ -68,7 +72,7 @@ class Grid:
         return self._num_rows, self._num_columns
 
 
-    def get_dimensions_absolute(self):
+    def get_dimensions_absolute(self) -> Tuple[int,int]:
         """Gets dimensions of grid in terminal characters
 
         Returns
@@ -82,7 +86,7 @@ class Grid:
         return self._height, self._width
 
 
-    def get_offsets(self):
+    def get_offsets(self) -> Tuple[int,int]:
         """Gets leftover characters for x and y
 
         Returns
@@ -96,7 +100,7 @@ class Grid:
         return self._offset_x, self._offset_y
 
 
-    def get_cell_dimensions(self):
+    def get_cell_dimensions(self) -> Tuple[int,int]:
         """Gets size in characters of single (row, column) cell location
 
         Returns
@@ -110,7 +114,7 @@ class Grid:
         return self._row_height, self._column_width
 
 
-    def set_num_rows(self, num_rows):
+    def set_num_rows(self, num_rows: int) -> None:
         """Sets the grid row size
         
         Parameters
@@ -131,7 +135,7 @@ class Grid:
         self._row_height = int(self._height / self._num_rows)
 
 
-    def set_num_cols(self, num_columns):
+    def set_num_cols(self, num_columns: int) -> None:
         """Sets the grid column size
         
         Parameters
@@ -153,7 +157,7 @@ class Grid:
         self._column_width  = int(self._width / self._num_columns)
 
 
-    def update_grid_height_width(self, height, width):
+    def update_grid_height_width(self, height: int, width: int):
         """Update grid height and width. Allows for on-the-fly size editing
         
         Parameters
@@ -184,4 +188,5 @@ class Grid:
         self._column_width   = int(self._width    / self._num_columns)
         self._offset_x       = self._width    % self._num_columns
         self._offset_y       = self._height   % self._num_rows
-        self._logger.info('Updated grid. Cell dims: {}x{}, Offsets {},{}'.format(self._row_height, self._column_width, self._offset_x, self._offset_y))
\ No newline at end of file
+        self._logger.debug(f'Updated grid. Cell dims: {self._row_height}x{self._column_width}, \
+                             Offsets {self._offset_x},{self._offset_y}')
