@@ -683,6 +683,14 @@ class MenuImplementation(UIImplementation):
         self._page_scroll_len  = 5
         self._view_items       = []
         self._on_selection_change: Optional[Callable[[Any],Any]] = None
+        self._stick_to_bottom = False
+
+    
+    def toggle_stick_to_bottom(self):
+        """Toggle option for keeping the viewport at the bottom of the items
+        """
+
+        self._stick_to_bottom = not self._stick_to_bottom
 
 
     def clear(self) -> None:
@@ -853,6 +861,9 @@ class MenuImplementation(UIImplementation):
         self._logger.debug(f'Adding item {str(item)} to menu')
         self._view_items.append(item)
 
+        if self._stick_to_bottom:
+            self.set_selected_item_index(len(self._view_items) - 1)
+
 
     def add_item_list(self, item_list: List[Any]) -> None:
 
@@ -925,6 +936,18 @@ class MenuImplementation(UIImplementation):
         return None
 
 
+    def is_empty(self) -> bool:
+        """Function that returns true if menu has no items within it, false otherwise
+
+        Returns
+        -------
+        bool
+            True if menu has no items, False otherwise. Identical to len(self._view_items) == 0
+        """
+
+        return len(self._view_items) == 0
+
+
     def set_selected_item(self, selected_item: Any):
         """Function that replaces the currently selected item with a new item
 
@@ -1189,6 +1212,8 @@ class TextBlockImplementation(UIImplementation):
 
         self._cursor_x = self._cursor_max_left
         self._cursor_y = self._cursor_max_up
+        self._viewport_y_start = 0
+        self._viewport_x_start = 0
         self._cursor_text_pos_x = 0
         self._cursor_text_pos_y = 0
         self._text_lines = []
