@@ -27,8 +27,9 @@ import py_cui
 import py_cui.ui
 import py_cui.colors
 import py_cui.errors
+import py_cui.debug
 
-from typing import Callable, List, Dict, Tuple, Any, Optional
+from typing import Union, Callable, List, Dict, Tuple, Any, Optional
 
 
 class Widget(py_cui.ui.UIElement):
@@ -84,18 +85,22 @@ class Widget(py_cui.ui.UIElement):
         self.update_height_width()
 
 
-    def add_key_command(self, key: int, command: Callable[[],Any]) -> Any:
+    def add_key_command(self, key: Union[int, List[int]], command: Callable[[],Any]) -> None:
         """Maps a keycode to a function that will be executed when in focus mode
 
         Parameters
         ----------
-        key : py_cui.keys.KEY
+        key : py_cui.keys.KEY_*
             ascii keycode used to map the key
         command : function without args
             a non-argument function or lambda function to execute if in focus mode and key is pressed
         """
 
-        self._key_commands[key] = command
+        if isinstance(key, list):
+            for value in key:
+                self._key_commands[value] = command
+        else:
+            self._key_commands[key] = command
 
 
     def add_mouse_command(self, mouse_event: int, command: Callable[[],Any]) -> None:
@@ -123,12 +128,12 @@ class Widget(py_cui.ui.UIElement):
         self._mouse_commands[mouse_event] = command
 
 
-    def update_key_command(self, key: int, command: Callable[[],Any]) -> Any:
+    def update_key_command(self, key: Union[int, List[int]], command: Callable[[],Any]) -> Any:
         """Maps a keycode to a function that will be executed when in focus mode, if key is already mapped
 
         Parameters
         ----------
-        key : py_cui.keys.KEY
+        key : py_cui.keys.KEY_*
             ascii keycode used to map the key
         command : function without args
             a non-argument function or lambda function to execute if in focus mode and key is pressed
@@ -165,6 +170,13 @@ class Widget(py_cui.ui.UIElement):
         self._text_color_rules.append(new_color_rule)
 
 
+    def clear_color_rules(self):
+        """Removes all configured color rules for the widget
+        """
+
+        self._text_color_rules.clear()
+
+
     def get_absolute_start_pos(self) -> Tuple[int,int]:
         """Gets the absolute position of the widget in characters. Override of base class function
 
@@ -306,7 +318,7 @@ class Widget(py_cui.ui.UIElement):
         # Retrieve the command function if it exists
         if mouse_event in self._mouse_commands.keys():
             command = self._mouse_commands[mouse_event]
-            
+
             # Identify num of args from callable. This allows for user to create commands that take in x, y
             # coords of the mouse press as input
             num_args = 0
@@ -407,7 +419,7 @@ class BlockLabel(Widget):
         Decides whether or not label should be centered
     """
 
-    def __init__(self, id, title: str,  grid: 'py_cui.grid.Grid', row: int, column: int, row_span: int, column_span: int, padx: int, pady: int, center, logger):
+    def __init__(self, id, title: str,  grid: 'py_cui.grid.Grid', row: int, column: int, row_span: int, column_span: int, padx: int, pady: int, logger: py_cui.debug.PyCUILogger, center: bool):
         """Initializer for blocklabel widget
         """
 
@@ -486,7 +498,7 @@ class ScrollMenu(Widget, py_cui.ui.MenuImplementation):
             if viewport_top <= y and viewport_top + len(self._view_items) - self._top_view >= y:
                 elem_clicked = y - viewport_top + self._top_view
                 self.set_selected_item_index(elem_clicked)
-        
+
             if self.get_selected_item_index() != current and self._on_selection_change is not None:
                 self._process_selection_change_event()
 
@@ -511,7 +523,7 @@ class ScrollMenu(Widget, py_cui.ui.MenuImplementation):
 
         current = self.get_selected_item_index()
         viewport_height = self.get_viewport_height()
-        
+
         if key_pressed == py_cui.keys.KEY_UP_ARROW:
             self._scroll_up()
         if key_pressed == py_cui.keys.KEY_DOWN_ARROW:
@@ -529,6 +541,20 @@ class ScrollMenu(Widget, py_cui.ui.MenuImplementation):
             self._process_selection_change_event()
 
 
+    def add_item(self, item):
+        """Override of add_item function, allows for sticking to bottom
+
+        Parameters
+        ----------
+        item : Object
+            Object to add to the menu. Must have implemented __str__ function
+        """
+
+        super().add_item(item)
+        if self._stick_to_bottom and self._top_view < (len(self._view_items) - self.get_viewport_height() - 1):
+            self._top_view = len(self._view_items) - self.get_viewport_height() - 1
+
+
     def _draw(self) -> None:
         """Overrides base class draw function
         """
@@ -537,6 +563,7 @@ class ScrollMenu(Widget, py_cui.ui.MenuImplementation):
         self._renderer.set_color_mode(self._color)
         self._renderer.draw_border(self)
         counter = self._pady + 1
+
         line_counter = 0
         for item in self._view_items:
             line = str(item)
@@ -671,7 +698,7 @@ class Button(Widget):
         self.command = command
         self.set_color(py_cui.MAGENTA_ON_BLACK)
         self.set_help_text('Focus mode on Button. Press Enter to press button, Esc to exit focus mode.')
-        
+
         # By default we will process command on click or double click
         if self.command is not None:
             self.add_mouse_command(py_cui.keys.LEFT_MOUSE_CLICK, self.command)
@@ -773,7 +800,7 @@ class TextBox(Widget, py_cui.ui.TextBoxImplementation):
             self._move_left()
         elif key_pressed == py_cui.keys.KEY_RIGHT_ARROW:
             self._move_right()
-        elif key_pressed == py_cui.keys.KEY_BACKSPACE:
+        elif key_pressed in py_cui.keys.KEY_BACKSPACE:
             self._erase_char()
         elif key_pressed == py_cui.keys.KEY_DELETE:
             self._delete_char()
@@ -857,7 +884,7 @@ class ScrollTextBlock(Widget, py_cui.ui.TextBlockImplementation):
         """
 
         Widget._handle_mouse_press(self, x, y, mouse_event)
-        
+
         if mouse_event == py_cui.keys.LEFT_MOUSE_CLICK:
             if y >= self._cursor_max_up and y <= self._cursor_max_down:
                 if x >= self._cursor_max_left and x <= self._cursor_max_right:
@@ -901,7 +928,7 @@ class ScrollTextBlock(Widget, py_cui.ui.TextBlockImplementation):
         # TODO: Fix this janky operation here
         elif key_pressed == py_cui.keys.KEY_DOWN_ARROW and self._cursor_text_pos_y < len(self._text_lines) - 1:
             self._move_down()
-        elif key_pressed == py_cui.keys.KEY_BACKSPACE:
+        elif key_pressed in py_cui.keys.KEY_BACKSPACE:
             self._handle_backspace()
         elif key_pressed == py_cui.keys.KEY_DELETE:
             self._handle_delete()
